Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(192)

Unified Diff: third_party/WebKit/public/web/WebUserGestureIndicator.h

Issue 2408333004: Move persistent gesture state to Document, add DocumentUserGestureToken (Closed)
Patch Set: Re-add dropped null check Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/public/web/WebScopedUserGesture.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/web/WebUserGestureIndicator.h
diff --git a/third_party/WebKit/public/web/WebUserGestureIndicator.h b/third_party/WebKit/public/web/WebUserGestureIndicator.h
index 7e2c3d947037ec922a3bcb14329e3a6dee05f4a5..44b1cacbd1413a3bb1b813d7e6ed635048693ad9 100644
--- a/third_party/WebKit/public/web/WebUserGestureIndicator.h
+++ b/third_party/WebKit/public/web/WebUserGestureIndicator.h
@@ -35,6 +35,7 @@
namespace blink {
+class WebLocalFrame;
class WebUserGestureToken;
class WebUserGestureIndicator {
@@ -46,9 +47,9 @@ class WebUserGestureIndicator {
// consumed.
BLINK_EXPORT static bool consumeUserGesture();
- // Returns true if a user gesture was processed on the current page since the
- // time the page was loaded.
- BLINK_EXPORT static bool processedUserGestureSinceLoad();
+ // Returns true if a user gesture was processed on the provided frame since
+ // the time the frame was loaded.
+ BLINK_EXPORT static bool processedUserGestureSinceLoad(WebLocalFrame*);
// Returns a token for the currently active user gesture. It can be used to
// continue processing the user gesture later on using a
« no previous file with comments | « third_party/WebKit/public/web/WebScopedUserGesture.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698